Cheshire3 Object Model - Transformer
====================================

.. _objects-transformer-api:

API
---

.. autoclass:: cheshire3.baseObjects.Transformer
   :members:


.. _objects-transformer-implementations:

Implementations
---------------

The following implementations are included in the distribution by default:

.. autoclass:: cheshire3.transformer.XmlTransformer

.. autoclass:: cheshire3.transformer.Bzip2XmlTransformer

.. autoclass:: cheshire3.transformer.SaxTransformer

.. autoclass:: cheshire3.transformer.WorkflowTransformer

.. autoclass:: cheshire3.transformer.LxmlXsltTransformer

.. autoclass:: cheshire3.transformer.LxmlOffsetQueryTermHighlightingTransformer

.. autoclass:: cheshire3.transformer.TemplatedTransformer

.. autoclass:: cheshire3.transformer.MarcTransformer
